pub fn advance_step(
current_step: Res<'_, State<CurrentStep>>,
next_step: ResMut<'_, NextState<CurrentStep>>,
)Expand description
Manages going forward a step on left click while placing track. Does not handle final step.
pub fn advance_step(
current_step: Res<'_, State<CurrentStep>>,
next_step: ResMut<'_, NextState<CurrentStep>>,
)Manages going forward a step on left click while placing track. Does not handle final step.